#include "HX711.h"

// HX711 circuit wiring
const int LOADCELL_DOUT_PIN = 26;
const int LOADCELL_SCK_PIN = 25;

HX711 scale;

const float Vref = 2.0;  // Reference voltage in volts
const int gain = 128;    // Gain factor for HX711
const long maxBits = 8388608;  // 2^23, the maximum code for 24-bit ADC

void setup() {
  Serial.begin(57600);
  scale.begin(LOADCELL_DOUT_PIN, LOADCELL_SCK_PIN);
}

void loop() {

  if (scale.is_ready()) {
    long reading = scale.read();

    // Calculate Vtc from the code
    float Vtc = (float(reading) * Vref) / (gain * maxBits);

    // Print raw reading and calculated voltage
    Serial.print("HX711 reading: ");
    Serial.print(reading);
    Serial.print(" => Vtc: ");
    Serial.print(Vtc, 6);  // 6 decimal places for precision
    Serial.println(" V");

    // TODO: Implement temperature conversion from Vtc (based on thermocouple calibration)

  } else {
    Serial.println("HX711 not found.");
  }

  delay(1000);
}
